Logo FSBarV1_Archived

EngineLauncher Module

Functions and values

Function or value Description

getSessionDir config

Full Usage: getSessionDir config

Parameters:
Returns: string

Get the session directory path for a given config.

config : EngineConfig
Returns: string

launchGraphical config scriptContent

Full Usage: launchGraphical config scriptContent

Parameters:
Returns: Process

Launch the graphical engine with the given script content.

config : EngineConfig
scriptContent : string
Returns: Process

launchHeadless config scriptContent

Full Usage: launchHeadless config scriptContent

Parameters:
Returns: Process

Launch the headless engine with the given script content.

config : EngineConfig
scriptContent : string
Returns: Process

stopEngine socketPath proc

Full Usage: stopEngine socketPath proc

Parameters:
    socketPath : string
    proc : Process

Stop an engine process and clean up socket/PID files.

socketPath : string
proc : Process

Type something to start searching.