Logo FSBarV1_Archived

GameFrame Type

A single simulation frame received from the engine, containing the frame number and all events that occurred during that frame.

Record fields

Record Field Description

Events

Full Usage: Events

Field type: GameEvent list

All game events that occurred during this frame.

Field type: GameEvent list

FrameNumber

Full Usage: FrameNumber

Field type: uint32

The engine simulation frame number (monotonically increasing).

Field type: uint32

Type something to start searching.