Logo FSBarV1_Archived

LoadedMap Type

Successful read result. Contains the fully materialised MapGrid (with LosMap/RadarMap initialised to zero arrays of the correct shape — dynamic layers are refreshed per frame by the caller) and the chokepoint list in findChokepoints output order.

Record fields

Record Field Description

BaseCentre

Full Usage: BaseCentre

Field type: float32 * float32 * float32
Field type: float32 * float32 * float32

Chokepoints

Full Usage: Chokepoints

Field type: Chokepoint list
Field type: Chokepoint list

Grid

Full Usage: Grid

Field type: MapGrid
Field type: MapGrid

MapName

Full Usage: MapName

Field type: string
Field type: string

Type something to start searching.