Logo FSBarV1_Archived

Path Type

A resolved path from start to goal (or a partial path under budget exhaustion).

Record fields

Record Field Description

EstimatedCost

Full Usage: EstimatedCost

Field type: float32

Total estimated traversal cost (sum of edge weights).

Field type: float32

Status

Full Usage: Status

Field type: PathStatus

Completion status.

Field type: PathStatus

Waypoints

Full Usage: Waypoints

Field type: (float32 * float32 * float32) array

Ordered world-coordinate waypoints, start → goal. Any two consecutive waypoints are connected by a straight line that is passable for the move type used to find this path.

Field type: (float32 * float32 * float32) array

Type something to start searching.