Logo FSBarV1_Archived

PathFailure Type

Reasons findPath can return Error.

Union cases

Union case Description

EndpointImpassable

Full Usage: EndpointImpassable

Start or goal is on a cell that the given move type cannot occupy.

NoRoute

Full Usage: NoRoute

A search completed within budget but no route exists.

OutOfBounds

Full Usage: OutOfBounds

Start or goal cell is outside the map bounds.

Instance members

Instance member Description

this.IsEndpointImpassable

Full Usage: this.IsEndpointImpassable

Returns: bool
Returns: bool

this.IsNoRoute

Full Usage: this.IsNoRoute

Returns: bool
Returns: bool

this.IsOutOfBounds

Full Usage: this.IsOutOfBounds

Returns: bool
Returns: bool

Type something to start searching.