Logo FSBarV1_Archived

BarInstallError Type

Failure modes surfaced by `detect`.

Union cases

Union case Description

DataDirNotFound path

Full Usage: DataDirNotFound path

Parameters:
    path : string

The resolved data directory (override or default) does not exist on disk.

path : string

EngineSubdirMissing path

Full Usage: EngineSubdirMissing path

Parameters:
    path : string

The data directory exists but does not contain an `engine/` subdirectory.

path : string

NoEngineVersions path

Full Usage: NoEngineVersions path

Parameters:
    path : string

The data directory and `engine/` subdirectory both exist but no `recoil_*` versions are installed.

path : string

OverriddenEngineNotFound version

Full Usage: OverriddenEngineNotFound version

Parameters:
    version : string

`HubSettings.EngineVersionOverride` names a version that does not exist under `/engine/`.

version : string

Instance members

Instance member Description

this.IsDataDirNotFound

Full Usage: this.IsDataDirNotFound

Returns: bool
Returns: bool

this.IsEngineSubdirMissing

Full Usage: this.IsEngineSubdirMissing

Returns: bool
Returns: bool

this.IsNoEngineVersions

Full Usage: this.IsNoEngineVersions

Returns: bool
Returns: bool

this.IsOverriddenEngineNotFound

Full Usage: this.IsOverriddenEngineNotFound

Returns: bool
Returns: bool

Type something to start searching.