Logo FSBarV1_Archived

SendCommandBatchResponse Type

Record fields

Record Field Description

BatchDiagnostic

Full Usage: BatchDiagnostic

Field type: string

Populated when the whole batch was rejected (e.g., oversize, no-session). Names the cap and received size when applicable.

Field type: string

ForwardedAtFrame

Full Usage: ForwardedAtFrame

Field type: int

Engine frame at which the accepted commands were forwarded. 0 when the whole batch was rejected (oversize, no session, etc.).

Field type: int

Outcomes

Full Usage: Outcomes

Field type: CommandOutcome list

1:1 with request.commands when the batch was accepted at the size-cap gate. Empty when the whole batch was rejected.

Field type: CommandOutcome list

Static members

Static member Description

SendCommandBatchResponse.Proto

Full Usage: SendCommandBatchResponse.Proto

Returns: Lazy<ProtoDef<SendCommandBatchResponse>>

SendCommandBatchResponse.empty

Full Usage: SendCommandBatchResponse.empty

Returns: SendCommandBatchResponse

Type something to start searching.