Logo FSBarV1_Archived

StreamGameFramesRequest Type

Record fields

Record Field Description

ClientLabel

Full Usage: ClientLabel

Field type: string

Optional client identifier for diagnostics. If empty, hub assigns a uuid.

Field type: string

CloseOnSessionEnd

Full Usage: CloseOnSessionEnd

Field type: bool

If true, the hub will close the stream when the current session ends (instead of keeping it open and waiting for the next session).

Field type: bool

Static members

Static member Description

StreamGameFramesRequest.Proto

Full Usage: StreamGameFramesRequest.Proto

Returns: Lazy<ProtoDef<StreamGameFramesRequest>>

StreamGameFramesRequest.empty

Full Usage: StreamGameFramesRequest.empty

Returns: StreamGameFramesRequest

Type something to start searching.