ConfigPanelInputResult Type
Result of `ConfigPanel.handleInput`: updated panel state, optional updated config, and an optional action to execute on the host.
Record fields
| Record Field |
Description
|
|
|
|
|
|
|
Result of `ConfigPanel.handleInput`: updated panel state, optional updated config, and an optional action to execute on the host.
| Record Field |
Description
|
|
|
|
|
|
|