EngineLauncher Module
Functions and values
| Function or value |
Description
|
|
|
Full Usage:
launchGraphical config scriptContent
Parameters:
EngineConfig
scriptContent : string
Returns: Process
|
Launch the graphical engine with the given script content.
|
Full Usage:
launchHeadless config scriptContent
Parameters:
EngineConfig
scriptContent : string
Returns: Process
|
Launch the headless engine with the given script content.
|
|
Stop an engine process and clean up socket/PID files.
|
FSBarV1_Archived