GameFrame Type
A single simulation frame received from the engine, containing the frame number and all events that occurred during that frame.
Record fields
| Record Field |
Description
|
All game events that occurred during this frame.
|
|
Full Usage:
FrameNumber
Field type: uint32
|
The engine simulation frame number (monotonically increasing).
|
FSBarV1_Archived