LoadedMap Type
Successful read result. Contains the fully materialised MapGrid (with LosMap/RadarMap initialised to zero arrays of the correct shape — dynamic layers are refreshed per frame by the caller) and the chokepoint list in findChokepoints output order.
Record fields
| Record Field |
Description
|
Full Usage:
BaseCentre
Field type: float32 * float32 * float32
|
|
|
|
|
|
Full Usage:
MapName
Field type: string
|
|
FSBarV1_Archived