SendCommandBatchResponse Type
Record fields
| Record Field |
Description
|
Full Usage:
BatchDiagnostic
Field type: string
|
Populated when the whole batch was rejected (e.g., oversize, no-session). Names the cap and received size when applicable.
|
Full Usage:
ForwardedAtFrame
Field type: int
|
Engine frame at which the accepted commands were forwarded. 0 when the whole batch was rejected (oversize, no session, etc.).
|
|
1:1 with request.commands when the batch was accepted at the size-cap gate. Empty when the whole batch was rejected.
|
Static members
| Static member |
Description
|
|
|
|
|
FSBarV1_Archived