StreamGameFramesRequest Type
Record fields
| Record Field |
Description
|
Full Usage:
ClientLabel
Field type: string
|
Optional client identifier for diagnostics. If empty, hub assigns a uuid.
|
Full Usage:
CloseOnSessionEnd
Field type: bool
|
If true, the hub will close the stream when the current session ends (instead of keeping it open and waiting for the next session).
|
Static members
| Static member |
Description
|
|
|
|
|
FSBarV1_Archived