ViewerCamera Type
Viewer-tab camera state. Pan + zoom are expressed as an origin in world coordinates and a scale factor. `AutoFit = true` makes the Viewer tab re-fit the scene to the viewport on each redraw; the Viewer UI flips it to `false` the first time the user manually pans or zooms.
Record fields
| Record Field |
Description
|
Full Usage:
AutoFit
Field type: bool
|
|
Full Usage:
OriginX
Field type: float32
|
|
Full Usage:
OriginY
Field type: float32
|
|
Full Usage:
Scale
Field type: float32
|
|
FSBarV1_Archived