PreviewSession Module
Offline preview and playback via SkiaViewer.
Functions and values
| Function or value |
Description
|
Full Usage:
advanceCycleIndex n direction current
Parameters:
int
direction : int
current : int
Returns: int
|
Pure helper exposed for unit testing: advance a cycling index by
|
Full Usage:
startPlayback frames gameFps
Parameters:
GameSnapshot seq
gameFps : int
Returns: IDisposable
|
Opens a viewer playing back a sequence of snapshots at the given game FPS, looping.
|
Full Usage:
startWithCachedMaps supportedMaps initialMapName
Parameters:
SupportedMap list
initialMapName : string option
Returns: IDisposable
|
Opens a viewer on the first map in
|
|
Opens a viewer showing the given map grid with the default layer.
|
|
|
Full Usage:
stop ()
Parameters:
unit
|
Stops the current preview session.
|
FSBarV1_Archived